@@ -18,17 +18,24 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include "config.h" // For GLOM_ENABLE_MAEMO
+#include <libglom/libglom_config.h> // For GLOM_ENABLE_MAEMO
  
-#include <glom/libglom/connectionpool.h>
-#include <glom/libglom/document/document_glom.h>
+#include <libglom/connectionpool.h>
+#include <libglom/document/document_glom.h>
 #include <bakery/bakery.h>
 //#include <libgdamm/connectionevent.h>
 #include <glibmm/i18n.h>
 
 #ifndef G_OS_WIN32
-#include <libepc/shell.h> //For epc_shell_set_progress_hooks().
-#include <libepc/publisher.h>
+# include <libepc/shell.h> //For epc_shell_set_progress_hooks().
+# include <libepc/publisher.h>
+#else
+// objidl.h, included by windows.h, defines a type called DATADIR, so we need
+// to undef it temporarily.
+# define GLOM_SAVE_DATADIR DATADIR
+# undef DATADIR
+# include <windows.h>
+# define DATADIR GLOM_SAVE_DATADIR
 #endif
 
 #ifdef GLOM_ENABLE_MAEMO
