@@ -18,9 +18,9 @@
  * Boston, MA 02111-1307, USA.
  */
 
-#include "config.h"
+#include <libglom/libglom_config.h>
 
-#include <glom/libglom/connectionpool_backends/postgres.h>
+#include <libglom/connectionpool_backends/postgres.h>
 #include <glibmm/i18n.h>
 #include <bakery/bakery.h>
 
