@@ -22,7 +22,7 @@
 #include "dialog_choose_relationship.h"
 #include "../layout_item_dialogs/dialog_buttonscript.h"
 #include "../layout_item_dialogs/dialog_notebook.h"
-#include <glom/libglom/glade_utils.h>
+#include <libglom/glade_utils.h>
 #include "../frame_glom.h" //For show_ok_dialog()
 //#include <libgnome/gnome-i18n.h>
 #include <bakery/App/App_Gtk.h> //For util_bold_message().
@@ -110,6 +110,7 @@ Dialog_Layout_Details::Dialog_Layout_Details(BaseObjectType* cobject, const Glib
 
 
     //Columns-count column:
+    //Note to translators: This is the number of columns in a group (group being a noun)
     m_treeview_column_group_columns = Gtk::manage( new Gtk::TreeView::Column(_("Group Columns")) );
     m_treeview_fields->append_column(*m_treeview_column_group_columns);
 
