@@ -24,6 +24,8 @@
 #include <bakery/App/App_Gtk.h> //For util_bold_message().
 #include <glibmm/i18n.h>
 
+namespace Glom
+{
 
 Dialog_Relationships::Dialog_Relationships(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade::Xml>& refGlade)
 : Dialog_Design(cobject, refGlade),
@@ -46,17 +48,17 @@ Dialog_Relationships::~Dialog_Relationships()
 
 /**
  * 
- * @param strTableName 
+ * @param table_name 
  */
-bool Dialog_Relationships::init_db_details(const Glib::ustring& strTableName)
+bool Dialog_Relationships::init_db_details(const Glib::ustring& table_name)
 {
   if(m_box)
   {
     m_box->load_from_document();
 
-    Dialog_Design::init_db_details(strTableName);
+    Dialog_Design::init_db_details(table_name);
 
-    return m_box->init_db_details(strTableName);
+    return m_box->init_db_details(table_name);
   }
 
   return false;
@@ -71,4 +73,5 @@ void Dialog_Relationships::on_hide()
   Dialog_Design::on_hide();
 }
 
+} //namespace Glom
 
