@@ -22,8 +22,8 @@
 #include "window_print_layout_edit.h"
 #include <glom/box_db_table.h>
 #include "canvas_layout_item.h"
-#include <glom/libglom/data_structure/layout/layoutitem_line.h>
-#include <glom/libglom/data_structure/layout/layoutitem_portal.h>
+#include <libglom/data_structure/layout/layoutitem_line.h>
+#include <libglom/data_structure/layout/layoutitem_portal.h>
 //#include <libgnome/gnome-i18n.h>
 #include <bakery/App/App_Gtk.h> //For util_bold_message().
 #include <gtkmm/scrolledwindow.h>
