@@ -49,10 +49,12 @@ Box_Tables::Box_Tables(BaseObjectType* cobject, const Glib::RefPtr<Gnome::Glade:
   refGlade->get_widget("checkbutton_show_hidden", m_pCheckButtonShowHidden);
   m_pCheckButtonShowHidden->signal_toggled().connect(sigc::mem_fun(*this, &Box_Tables::on_show_hidden_toggled));
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
   m_AddDel.signal_user_added().connect(sigc::mem_fun(*this, &Box_Tables::on_adddel_Add));
   m_AddDel.signal_user_requested_delete().connect(sigc::mem_fun(*this, &Box_Tables::on_adddel_Delete));
-  m_AddDel.signal_user_requested_edit().connect(sigc::mem_fun(*this, &Box_Tables::on_adddel_Edit));
   m_AddDel.signal_user_changed().connect(sigc::mem_fun(*this, &Box_Tables::on_adddel_changed));
+#endif //GLOM_ENABLE_CLIENT_ONLY
+  m_AddDel.signal_user_requested_edit().connect(sigc::mem_fun(*this, &Box_Tables::on_adddel_Edit));
 
   show_all_children();
 }
@@ -144,23 +146,24 @@ bool Box_Tables::fill_from_database()
 #else
   std::auto_ptr<ExceptionConnection> error;
   sharedptr<SharedConnection> sharedconnection = connect_to_server(App_Glom::get_application(), error);
-  // Ignore error, sharedconnection presence is checked below
+  // Ignore error because sharedconnection presence is checked below.
 #endif
+
   if(sharedconnection)
   {
     m_AddDel.remove_all();
     Glib::RefPtr<Gnome::Gda::Connection> connection = sharedconnection->get_gda_connection();
 
-    type_vecStrings vecTables = get_table_names_from_database();
+    const type_vecStrings vecTables = get_table_names_from_database();
 
-    for(type_vecStrings::iterator iter = vecTables.begin(); iter != vecTables.end(); iter++)
+    for(type_vecStrings::const_iterator iter = vecTables.begin(); iter != vecTables.end(); iter++)
     {
       const Glib::ustring strName = *iter;
 
       sharedptr<TableInfo> table_info;
 
       //Check whether it should be hidden:
-      Document_Glom::type_listTableInfo::iterator iterFind = std::find_if(listTablesDocument.begin(), listTablesDocument.end(), predicate_FieldHasName<TableInfo>(strName));
+      Document_Glom::type_listTableInfo::const_iterator iterFind = std::find_if(listTablesDocument.begin(), listTablesDocument.end(), predicate_FieldHasName<TableInfo>(strName));
       if(iterFind != listTablesDocument.end())
       {
         table_info = *iterFind;
@@ -179,7 +182,7 @@ bool Box_Tables::fill_from_database()
       const bool hidden = table_info->m_hidden;
 
       bool bAddIt = true;
-      if(hidden && !developer_mode)  //Don't add hidden tables unless we are in developer mode:
+      if(hidden && !developer_mode) //Don't add hidden tables unless we are in developer mode:
         bAddIt = false;
 
       if(hidden && !m_pCheckButtonShowHidden->get_active()) //Don't add hidden tables if that checkbox is unset.
@@ -191,9 +194,7 @@ bool Box_Tables::fill_from_database()
       const Glib::ustring prefix = "glom_system_";
       const Glib::ustring table_prefix = strName.substr(0, prefix.size());
       if(table_prefix == prefix)
-      {
         bAddIt = false;
-      }
 
       if(bAddIt)
       {
@@ -209,6 +210,7 @@ bool Box_Tables::fill_from_database()
   return result;
 }
 
+#ifndef GLOM_ENABLE_CLIENT_ONLY
 void Box_Tables::on_adddel_Add(const Gtk::TreeModel::iterator& row)
 {
   //TODO: Handle cell renderer changes to prevent illegal table names (e.g. starting with numbers.).
@@ -301,7 +303,7 @@ void Box_Tables::on_adddel_Delete(const Gtk::TreeModel::iterator& rowStart, cons
           //Delete the table:
           if(iButtonClicked == Gtk::RESPONSE_OK)
           {
-            const bool test = query_execute( "DROP TABLE \"" + table_name + "\"", App_Glom::get_application());
+            const bool test = query_execute( "DROP TABLE \"" + table_name + "\"");
             if(!test)
               std::cerr << "Box_Tables::on_adddel_Delete(): DROP TABLE failed." << std::endl;
             else
@@ -323,6 +325,75 @@ void Box_Tables::on_adddel_Delete(const Gtk::TreeModel::iterator& rowStart, cons
   }
 }
 
+
+void Box_Tables::on_adddel_changed(const Gtk::TreeModel::iterator& row, guint column)
+{
+  if(get_userlevel() == AppState::USERLEVEL_DEVELOPER)
+  {
+    if(column == m_colHidden)
+    {
+      save_to_document();
+      //TODO: This causes a crash. fill_from_database(); //Hide/show the table.
+    }
+    else if(column == m_colTitle)
+    {
+      save_to_document();
+    }
+    else if(column == m_colDefault)
+    {
+      //Only one table can be the default, so ensure that:
+      const bool is_default = m_AddDel.get_value_as_bool(row, m_colDefault);
+      if(is_default)
+      {
+        //Set all the other rows to false:
+        Glib::RefPtr<Gtk::TreeModel> model = m_AddDel.get_model();
+        for(Gtk::TreeModel::iterator iter = model->children().begin(); iter != model->children().end(); ++iter)
+        {
+          if(iter != row)
+            m_AddDel.set_value(iter, m_colDefault, false);
+        }
+      }
+
+      save_to_document();
+    }
+    else if(column == m_colTableName)
+    {
+      Glib::ustring table_name = m_AddDel.get_value_key(row);
+      Glib::ustring table_name_new = m_AddDel.get_value(row, m_colTableName);
+      if(!table_name.empty() && !table_name_new.empty())
+      {
+        Glib::ustring strMsg = _("Are you sure that you want to rename this table?");  //TODO: Show old and new names?
+        Gtk::MessageDialog dialog(_("<b>Rename Table</b>"), true, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE );
+        dialog.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
+        dialog.add_button(_("Rename"), Gtk::RESPONSE_OK);
+        dialog.set_secondary_text(strMsg);
+        int iButtonClicked = dialog.run();
+
+        //Rename the table:
+        if(iButtonClicked == Gtk::RESPONSE_OK)
+        {
+          const bool test = query_execute( "ALTER TABLE \"" + table_name + "\" RENAME TO \"" + table_name_new + "\"");
+          if(test)
+          {
+            //Change the AddDel item's key:
+            m_AddDel.set_value_key(row, table_name_new);
+
+            set_modified();
+
+            //Tell the document that this table's name has changed:
+            Document_Glom* document = get_document();
+            if(document)
+              document->change_table_name(table_name, table_name_new);
+
+            //fill_from_database(); //We should not modify the model structure in a cellrenderer signal handler.
+          }
+        }
+      }
+    }
+  }
+}
+#endif //GLOM_ENABLE_CLIENT_ONLY
+
 void Box_Tables::on_adddel_Edit(const Gtk::TreeModel::iterator& row)
 {
   Glib::ustring table_name = m_AddDel.get_value_key(row);
@@ -381,7 +452,7 @@ void Box_Tables::save_to_document()
     }
 
     if(document)
-      document->set_tables( listTables); //TODO: Don't save all new tables - just the ones already in the document.
+      document->set_tables(listTables); //TODO: Don't save all new tables - just the ones already in the document.
   }
 }
 
@@ -390,73 +461,6 @@ void Box_Tables::on_show_hidden_toggled()
   fill_from_database();
 }
 
-void Box_Tables::on_adddel_changed(const Gtk::TreeModel::iterator& row, guint column)
-{
-  if(get_userlevel() == AppState::USERLEVEL_DEVELOPER)
-  {
-    if(column == m_colHidden)
-    {
-      save_to_document();
-      //TODO: This causes a crash. fill_from_database(); //Hide/show the table.
-    }
-    else if(column == m_colTitle)
-    {
-      save_to_document();
-    }
-    else if(column == m_colDefault)
-    {
-      //Only one table can be the default, so ensure that:
-      const bool is_default = m_AddDel.get_value_as_bool(row, m_colDefault);
-      if(is_default)
-      {
-        //Set all the other rows to false:
-        Glib::RefPtr<Gtk::TreeModel> model = m_AddDel.get_model();
-        for(Gtk::TreeModel::iterator iter = model->children().begin(); iter != model->children().end(); ++iter)
-        {
-          if(iter != row)
-            m_AddDel.set_value(iter, m_colDefault, false);
-        }
-      }
-
-      save_to_document();
-    }
-    else if(column == m_colTableName)
-    {
-      Glib::ustring table_name = m_AddDel.get_value_key(row);
-      Glib::ustring table_name_new = m_AddDel.get_value(row, m_colTableName);
-      if(!table_name.empty() && !table_name_new.empty())
-      {
-        Glib::ustring strMsg = _("Are you sure that you want to rename this table?");  //TODO: Show old and new names?
-        Gtk::MessageDialog dialog(_("<b>Rename Table</b>"), true, Gtk::MESSAGE_QUESTION, Gtk::BUTTONS_NONE );
-        dialog.add_button(Gtk::Stock::CANCEL, Gtk::RESPONSE_CANCEL);
-        dialog.add_button(_("Rename"), Gtk::RESPONSE_OK);
-        dialog.set_secondary_text(strMsg);
-        int iButtonClicked = dialog.run();
-
-        //Rename the table:
-        if(iButtonClicked == Gtk::RESPONSE_OK)
-        {
-          const bool test = query_execute( "ALTER TABLE \"" + table_name + "\" RENAME TO \"" + table_name_new + "\"", App_Glom::get_application());
-          if(test)
-          {
-            //Change the AddDel item's key:
-            m_AddDel.set_value_key(row, table_name_new);
-
-            set_modified();
-
-            //Tell the document that this table's name has changed:
-            Document_Glom* document = get_document();
-            if(document)
-              document->change_table_name(table_name, table_name_new);
-
-            //fill_from_database(); //We should not modify the model structure in a cellrenderer signal handler.
-          }
-        }
-      }
-    }
-  }
-}
-
 void Box_Tables::on_userlevel_changed(AppState::userlevels /* userlevel */)
 {
   fill_from_database();
