@@ -22,16 +22,16 @@
 #define GLOM_DB_ADDDEL_H
 
 #include <gtkmm.h>
-#include <glom/libglom/data_structure/layout/layoutitem_field.h>
+#include <libglom/data_structure/layout/layoutitem_field.h>
 #include <libgdamm.h>
-#include <glom/utility_widgets/db_adddel/treemodel_with_addrow.h>
-#include <glom/libglom/document/document_glom.h>
+#include "glom_db_treemodel.h"
+#include <libglom/document/document_glom.h>
 #include <glom/base_db_table_data.h>
 
 #include <vector>
 #include <map>
 
-#include "config.h" // For GLOM_ENABLE_CLIENT_ONLY
+#include <libglom/libglom_config.h> // For GLOM_ENABLE_CLIENT_ONLY
 
 namespace Glom
 {
@@ -259,14 +259,15 @@ public:
 
   virtual void set_open_button_title(const Glib::ustring& title);
 
-protected:
+private:
   
   
   //Overrides of Base_DB/Base_DB_Table methods:
   virtual void set_entered_field_data(const sharedptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value);
   virtual void set_entered_field_data(const Gtk::TreeModel::iterator& row, const sharedptr<const LayoutItem_Field>& field, const Gnome::Gda::Value& value);
   virtual Gnome::Gda::Value get_entered_field_data(const sharedptr<const LayoutItem_Field>& field) const;
-
+  virtual Gtk::TreeModel::iterator get_row_selected();
+ 
   //Implementations of pure virtual methods from Base_DB_Table_Data:
   virtual sharedptr<Field> get_field_primary_key() const;
   virtual Gnome::Gda::Value get_primary_key_value_selected() const;
@@ -285,7 +286,10 @@ protected:
   ///Return the query column index of any columns that display this field:
   type_list_indexes get_data_model_column_index(const sharedptr<const LayoutItem_Field>& layout_item_field) const;
 
+protected:
   virtual void setup_menu();
+
+private:
   virtual Gnome::Gda::Value treeview_get_key(const Gtk::TreeModel::iterator& row) const;
 
   ///Add a blank row, or return the existing blank row if there already is one.
@@ -303,10 +307,13 @@ protected:
 
   virtual bool on_button_press_event_Popup(GdkEventButton* event);
 
+protected:
   void on_MenuPopup_activate_Edit();
   void on_MenuPopup_activate_Add();
   void on_MenuPopup_activate_Delete();
 
+private:
+
 #ifndef GLOM_ENABLE_CLIENT_ONLY
   void on_MenuPopup_activate_layout();
 #endif
@@ -360,9 +367,9 @@ protected:
   Gtk::TreeView m_TreeView;
   Gtk::TreeModel::ColumnRecord m_ColumnRecord;
 
-  //Either a db-backed model, or a liststore-derived find-criteria model:
-  TreeModelWithAddRow* m_refListStore; //We use this without a Glib::RefPtr to avoid the complication of ObjectBase as an MI base.
-  Glib::RefPtr<Gtk::TreeModel> m_refListStore_as_model; //To avoid repeated dynamic_casts.
+  //typedef Gtk::ListStore type_model_store;
+  typedef DbTreeModel type_model_store;
+  Glib::RefPtr<type_model_store> m_refListStore;
 
   //Columns, not including the hidden internal columns:
   typedef std::vector<DbAddDelColumnInfo> type_ColumnTypes;
@@ -373,8 +380,10 @@ protected:
   bool m_column_sorted_direction; //true means ascending. 
   guint m_column_sorted; //Previously-clicked (on the treeview header) column. Remember it so we can reverse the sort order on a second click.
 
+protected:
   Glib::ustring m_open_button_title; //Allow us to change "Open" to "Select".
 
+private:
   //TODO: Avoid repeating these in so many widgets:
   Gtk::Menu* m_pMenuPopup;
   Glib::RefPtr<Gtk::ActionGroup> m_refActionGroup;
@@ -392,8 +401,11 @@ protected:
 
   type_vecStrings m_vecColumnIDs; //We give each ViewColumn a special ID, so we know where they are after a reorder.
 
+protected:
   bool m_allow_add;
   bool m_allow_delete;
+
+private:
     
   bool m_find_mode;
   bool m_allow_only_one_related_record;
@@ -430,7 +442,7 @@ protected:
     InnerIgnore(DbAddDel* pOuter);
     ~InnerIgnore();
 
-  protected:
+  private:
     DbAddDel* m_pOuter;
     bool m_bPreventUserSignals, m_bIgnoreTreeViewSignals;
   };
